@@ -276,9 +276,12 @@ class MySQLCollector(diamond.collector.Collector):
     def get_db_stats(self, query):
         cursor = self.db.cursor(cursorclass=MySQLdb.cursors.DictCursor)
 
-        cursor.execute(query)
-
-        return cursor.fetchall()
+        try:
+            cursor.execute(query)
+            return cursor.fetchall()
+        except MySQLError, e:
+            self.log.error('MySQLCollector could not get db stats', e)
+            return ()
 
     def connect(self, params):
         try:
@@ -305,12 +308,11 @@ class MySQLCollector(diamond.collector.Collector):
         return self.get_db_stats('SHOW ENGINE INNODB STATUS')
 
     def get_stats(self, params):
-        metrics = {}
+        metrics = {'status': {}}
 
         if not self.connect(params):
             return metrics
 
-        metrics['status'] = {}
         rows = self.get_db_global_status()
         for row in rows:
             try:
@@ -428,6 +430,9 @@ class MySQLCollector(diamond.collector.Collector):
                 '^([^:]*):([^@]*)@([^:]*):?([^/]*)/([^/]*)/?(.*)', host)
 
             if not matches:
+                self.log.error(
+                    'Connection string not in required format, skipping: %s',
+                    host)
                 continue
 
             params = {}
@@ -448,11 +453,15 @@ class MySQLCollector(diamond.collector.Collector):
             try:
                 metrics = self.get_stats(params=params)
             except Exception, e:
+                try:
+                    self.disconnect()
+                except MySQLdb.ProgrammingError:
+                    pass
                 self.log.error('Collection failed for %s %s', nickname, e)
                 continue
 
             # Warn if publish contains an unknown variable
-            if 'publish' in self.config:
+            if 'publish' in self.config and metrics['status']:
                     for k in self.config['publish'].split():
                         if k not in metrics['status']:
                             self.log.error("No such key '%s' available, issue"
