@@ -31,13 +31,41 @@ class ArchiveHandler(Handler):
             filename=self.config['log_file'],
             when='midnight',
             interval=1,
-            backupCount=int(self.config.get('days', 7)),
-            encoding=self.config.get('encoding', None)
+            backupCount=int(self.config['days']),
+            encoding=self.config['encoding']
             )
         handler.setFormatter(formatter)
         handler.setLevel(logging.DEBUG)
         self.archive.addHandler(handler)
 
+    def get_default_config_help(self):
+        """
+        Returns the help text for the configuration options for this handler
+        """
+        config = super(ArchiveHandler, self).get_default_config_help()
+
+        config.update({
+            'log_file': 'Path to the logfile',
+            'days': 'How many days to store',
+            'encoding': '',
+        })
+
+        return config
+
+    def get_default_config(self):
+        """
+        Return the default config for the handler
+        """
+        config = super(ArchiveHandler, self).get_default_config()
+
+        config.update({
+            'log_file': '',
+            'days': 7,
+            'encoding': None,
+        })
+
+        return config
+
     def process(self, metric):
         """
         Send a Metric to the Archive.
