@@ -35,6 +35,30 @@ class zmqHandler (Handler):
         # Create ZMQ pub socket and bind
         self._bind()
 
+    def get_default_config_help(self):
+        """
+        Returns the help text for the configuration options for this handler
+        """
+        config = super(zmqHandler, self).get_default_config_help()
+
+        config.update({
+            'port': '',
+        })
+
+        return config
+
+    def get_default_config(self):
+        """
+        Return the default config for the handler
+        """
+        config = super(zmqHandler, self).get_default_config()
+
+        config.update({
+            'port': 1234,
+        })
+
+        return config
+
     def _bind(self):
         """
            Create PUB socket and bind
